@@ -15,9 +15,11 @@ from pulpcore.client.pulp_ansible.api.galaxy_detail_api import GalaxyDetailApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_collections_api import PulpAnsibleGalaxyApiCollectionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v2_versions_api import PulpAnsibleGalaxyApiV2VersionsApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_all_api import PulpAnsibleGalaxyApiV3AllApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_api import PulpAnsibleGalaxyApiV3CollectionsApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_docs_blob_api import PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_versions_api import PulpAnsibleGalaxyApiV3VersionsApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_v3_api import PulpAnsibleGalaxyV3Api
 from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
 from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
 from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
